pub struct Meta { /* private fields */ }Expand description
Descriptive metadata for an atlas run. Native schema versioning belongs to AtlasDocument.
Implementations
Sourceimpl Meta
impl Meta
pub fn app(&self) -> &str
pub fn version(&self) -> &str
pub fn format(&self) -> &str
pub const fn scale(&self) -> f32
Sourcepub const fn power_of_two(&self) -> bool
pub const fn power_of_two(&self) -> bool
Returns whether power-of-two output sizing was applied to every page.
Sourcepub const fn square(&self) -> bool
pub const fn square(&self) -> bool
Returns whether square output sizing was applied to every page.
Sourcepub const fn max_dimensions(&self) -> (u32, u32)
pub const fn max_dimensions(&self) -> (u32, u32)
Returns an upper bound for every output page dimension.
pub const fn extrude(&self) -> u32
pub const fn allow_rotation(&self) -> bool
pub fn trim_mode(&self) -> &str
pub const fn background_color(&self) -> Option<[u8; 4]>